Module presentation

Module presentation 

Functions

char_display_width
Returns the display width of a single Unicode character.
display_width
Returns the display width of a string, accounting for Unicode double-width and combining characters.