Module quote

Module quote 

Structs

Quoted
A wrapper for a value to be quoted with a given style.

Enums

QuoteStyle
The style of quoting to use: single or double quotes.

Functions

q
Return a Quoted wrapper using single quotes for diagnostic quoting.
qq
Return a Quoted wrapper using double quotes (default).
quoted
Return a Quoted wrapper for the given value and quote style.